@@ -1,31 +1,26 @@
 package Data::Serializer::FreezeThaw;
 BEGIN { @Data::Serializer::FreezeThaw::ISA = qw(Data::Serializer) }
 
-
+use warnings;
 use strict;
 use FreezeThaw;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA);
 
-require Exporter;
-require AutoLoader;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 
-# Preloaded methods go here.
+sub serialize {
+    return FreezeThaw::freeze($_[1]);
+}
 
-# Autoload methods go after =cut, and are processed by the autosplit program.
+sub deserialize {
+    my ($obj) = FreezeThaw::thaw($_[1]);
+    return $obj;
+}
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+# 
 
 =head1 NAME
 
@@ -39,6 +34,15 @@ Data::Serializer::FreezeThaw - Creates bridge between Data::Serializer and Freez
 
 Module is used internally to Data::Serializer
 
+
+=over 4
+
+=item B<serialize> - Wrapper to normalize serializer method name
+
+=item B<deserialize> - Wrapper to normalize deserializer method name
+
+=back
+
 =head1 AUTHOR
 
 Neil Neely <neil@neely.cx>
@@ -55,11 +59,3 @@ perl(1), Data::Serializer(3), FreezeThaw(3).
 
 =cut
 
-sub serialize {
-    return FreezeThaw::freeze($_[1]);
-}
-
-sub deserialize {
-    my ($obj) = FreezeThaw::thaw($_[1]);
-    return $obj;
-}
